==> Mopidy-Mobile-0.0.1.tar.gz: Mopidy-Mobile-0.0.1/mopidy_mobile/www/js/app.js <==
angular.module('app', ['ionic', 'app.controllers', 'app.services'])

.filter('encode', function() {
  return window.encodeURIComponent;
})

.config(function($stateProvider, $urlRouterProvider, $ionicConfigProvider, MopidyProvider) {
  $stateProvider
    .state('tabs', {
      abstract: true,
      url: '/tabs',
      templateUrl: 'templates/tabs.html'
    })
    .state('tabs.playback', {
      url: '/playback',
      views: {
        'playback': {
          templateUrl: 'templates/playback.html',
          controller: 'PlaybackCtrl'
        }
      }
    })
    .state('tabs.tracklist', {
      url: '/tracklist',
      views: {
        'tracklist': {
          templateUrl: 'templates/tracklist.html',
          controller: 'TracklistCtrl'
        }
      }
    })
    .state('tabs.library', {
      abstract: true,
      url: '/library',
      views: {
        'library': {
          template: '<ion-nav-view></ion-nav-view>(Library)',
        }
      }
    })
    .state('tabs.library.root', {
      url: '',
      templateUrl: 'templates/browse.html',
      controller: 'LibraryCtrl',
      data: { 'handler': 'root' },
    })
    .state('tabs.library.browse', {
      url: '/browse?name&uri',
      templateUrl: 'templates/browse.html',
      controller: 'LibraryCtrl',
      data: { 'handler': 'browse' },
    })
    .state('tabs.library.search', {
      url: '/search/?q',
      templateUrl: 'templates/search.html',
      controller: 'LibraryCtrl',
      data: { 'handler': 'search' },
    })
    .state('tabs.playlists', {
      url: '/playlists',
      views: {
        'playlists': {
          templateUrl: 'templates/playlists.html',
          controller: 'PlaylistsCtrl'
        }
      }
    })
    .state('tabs.settings', {
      url: '/settings',
      views: {
        'settings': {
          templateUrl: 'templates/settings.html',
          controller: 'SettingsCtrl'
        }
      }
    });

  $urlRouterProvider.otherwise('/tabs/playback');

  // TODO: platform defaults/configurable?
  $ionicConfigProvider.tabs.position('bottom');
  $ionicConfigProvider.tabs.style('standard');

  // mopidy defaults
  MopidyProvider.settings.backoffDelayMin = 250;
  MopidyProvider.settings.backoffDelayMax = 1000;
  MopidyProvider.settings.callingConvention = 'by-position-or-by-name';
})

.run(function($ionicPlatform) {
  $ionicPlatform.ready(function() {
    // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
    // for form inputs)
    if (window.cordova && window.cordova.plugins.Keyboard) {
      window.cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
    }
    //if (window.StatusBar) {
    //  // org.apache.cordova.statusbar required
    //  StatusBar.styleDefault();
    //}
  });
});

==> Mopidy-Mobile-0.0.2.tar.gz: Mopidy-Mobile-0.0.2/mopidy_mobile/www/js/app.js <==
angular.module('app', [
  'ionic',
  'pascalprecht.translate',
  'app.controllers',
  'app.directives',
  'app.services'
])

.filter('encode', function() {
  return window.encodeURIComponent;
})

.config(function($stateProvider, $urlRouterProvider, $ionicConfigProvider, $translateProvider, ConfigProvider, MopidyProvider) {
  $stateProvider
    .state('tabs', {
      abstract: true,
      url: '/tabs',
      templateUrl: 'templates/tabs.html'
    })
    .state('tabs.playback', {
      url: '/playback',
      views: {
        'playback': {
          templateUrl: 'templates/playback.html',
          controller: 'PlaybackCtrl'
        }
      }
    })
    .state('tabs.tracklist', {
      url: '/tracklist',
      views: {
        'tracklist': {
          templateUrl: 'templates/tracklist.html',
          controller: 'TracklistCtrl'
        }
      }
    })
    .state('tabs.library', {
      abstract: true,
      url: '/library',
      views: {
        'library': {
          template: '<ion-nav-view></ion-nav-view>(Library)',
        }
      }
    })
    .state('tabs.library.root', {
      url: '',
      templateUrl: 'templates/browse.html',
      controller: 'LibraryCtrl',
      data: { 'handler': 'root' },
    })
    .state('tabs.library.browse', {
      url: '/browse?name&uri',
      templateUrl: 'templates/browse.html',
      controller: 'LibraryCtrl',
      data: { 'handler': 'browse' },
    })
    .state('tabs.library.search', {
      url: '/search/?q',
      templateUrl: 'templates/search.html',
      controller: 'LibraryCtrl',
      data: { 'handler': 'search' },
    })
    .state('tabs.playlists', {
      url: '/playlists',
      views: {
        'playlists': {
          templateUrl: 'templates/playlists.html',
          controller: 'PlaylistsCtrl'
        }
      }
    })
    .state('tabs.settings', {
      url: '/settings',
      views: {
        'settings': {
          templateUrl: 'templates/settings.html',
          controller: 'SettingsCtrl'
        }
      }
    });

  $urlRouterProvider.otherwise('/tabs/playback');

  // TODO: platform defaults/configurable?
  $ionicConfigProvider.tabs.position('bottom');
  $ionicConfigProvider.tabs.style('standard');

  // TODO: move to external ressoucres?
  $translateProvider.translations('en', {
    'Playback': 'Playback',
    'Tracklist': 'Tracklist',
    'Library': 'Library',
    'Playlists': 'Playlists',
    'Settings': 'Settings',
    'Language': 'Language',
    'Theme': 'Theme',
    'Nothing playing': 'Nothing playling',
    'Pull to refresh': 'Pull to refresh',
    'Search here...': 'Search here...',
    'Edit': 'Edit',
    'Clear': 'Clear',
    'Save': 'Save',
    'Remove': 'Remove',
    'None': 'None',  // FIXME
  });

  $translateProvider.translations('de', {
    'Playback': 'Wiedergabe',
    'Tracklist': 'Titel',
    'Library': 'Bibliothek',
    'Playlists': 'Listen',
    'Settings': 'Einstellungen',
    'Language': 'Sprache',
    'Theme': 'Thema',
    'Nothing playing': 'Nichts spielt',
    'Pull to refresh': 'Ziehen zum Aktualisieren',
    'Search here...': 'Hier suchen...',
    'Edit': 'Bearbeiten',
    'Clear': 'Leeren',
    'Save': 'Speichern',
    'Remove': 'Löschen',
    'None': 'Nix',  // FIXME
  });

  $translateProvider.preferredLanguage(ConfigProvider.get('language', 'en'));

  // mopidy defaults
  MopidyProvider.settings.backoffDelayMin = 250;
  MopidyProvider.settings.backoffDelayMax = 1000;
  MopidyProvider.settings.callingConvention = 'by-position-or-by-name';
})

.run(function($ionicPlatform) {
  $ionicPlatform.ready(function() {
    // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
    // for form inputs)
    if (window.cordova && window.cordova.plugins.Keyboard) {
      window.cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
    }
    //if (window.StatusBar) {
    //  // org.apache.cordova.statusbar required
    //  StatusBar.styleDefault();
    //}
  });
});
